import { dataSource } from "../../../data-source";
import { equipmentType } from "../../../entity/unit/equipment/equipmentType";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class EquipmentTypeService {
  /**
   * @description get all equipmentTypes
   * @returns {Promise<Array<equipmentType>>}
   */
  static async getAll(): Promise<Array<equipmentType>> {
    return await dataSource
      .getRepository(equipmentType)
      .createQueryBuilder("equipmentType")
      .orderBy("type", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "equipmentType", err);
      });
  }

  /**
   * @description get equipmentType by id
   * @returns {Promise<equipmentType>}
   */
  static async getById(id: string): Promise<equipmentType> {
    return await dataSource
      .getRepository(equipmentType)
      .createQueryBuilder("equipmentType")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "equipmentType", err);
      });
  }
}
